@@ -9,17 +9,12 @@
 #
 package Task::BeLike::RSRCHBOY;
 {
-  $Task::BeLike::RSRCHBOY::VERSION = '0.001';
+  $Task::BeLike::RSRCHBOY::VERSION = '0.002';
 }
 
 # ABSTRACT: Modules RSRCHBOY uses!
 
-use 5.12.1;
-use warnings;
-
-
-
-1;
+!!42;
 
 
 
@@ -31,14 +26,12 @@ Task::BeLike::RSRCHBOY - Modules RSRCHBOY uses!
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 TASK CONTENTS
 
 =head2 CPAN/GitHub Tools
 
-=head3 L<perl> 5.12.1
-
 =head3 L<App::cpanminus>
 
 =head3 L<App::cpanoutdated>
@@ -49,6 +42,8 @@ version 0.001
 
 =head3 L<Dist::Zilla::PluginBundle::RSRCHBOY>
 
+=head3 L<Git::CPAN::Patch>
+
 =head2 DB bits
 
 =head3 L<DBD::SQLite> 1.31
@@ -57,14 +52,18 @@ version 0.001
 
 =head3 L<DBIx::Class::Schema::Loader> 0.07010
 
+=head2 Date/Time handling
+
+=head3 L<DateTime>
+
+=head3 L<DateTime::Format::DB2>
+
 =head3 L<DateTime::Format::DBI>
 
 =head3 L<DateTime::Format::MySQL>
 
 =head3 L<DateTime::Format::Pg>
 
-=head3 L<DateTime::Format::DB2>
-
 =head2 Hygiene
 
 =head3 L<common::sense>
@@ -75,7 +74,7 @@ version 0.001
 
 =head3 L<Perl::Critic>
 
-=head2 Mooseish bits
+=head2 Class bits
 
 =head3 L<Any::Moose>
 
@@ -83,51 +82,27 @@ version 0.001
 
 =head3 L<Role::Basic>
 
-=head3 L<Moose> 2
-
-=head3 L<MooseX::AlwaysCoerce>
+=head3 L<Reindeer> 0.008
 
 =head3 L<MooseX::App::Cmd>
 
-=head3 L<MooseX::AttributeShortcuts> 0.005
-
 =head3 L<MooseX::AutoDestruct> 0.007
 
-=head3 L<MooseX::Types>
+=head3 L<MooseX::TrackDirty::Attributes> 2.000
 
-=head3 L<MooseX::Types::Path::Class>
+Version 2.000 required because: native traits support
 
 =head3 L<MooseX::Types::Perl>
 
-=head2 Web
-
-=head3 L<Catalyst::Runtime> 5.9
-
-=head3 L<Catalyst::Devel>
-
-=head3 L<Catalyst::Controller::REST>
-
-=head3 L<Catalyst::Model::DBIC::Schema>
-
-=head3 L<Catalyst::View::TT>
-
-=head3 L<Task::Catalyst>
-
-=head3 L<Dancer>
-
-=head3 L<Plack::Middleware::Debug>
-
-=head3 L<Plack::Middleware::SetAccept>
-
 =head2 Other Libraries I Use
 
+=head3 L<aliased>
+
 =head3 L<opts> 0.05
 
-Version 0.05 required because: for simple one-off scripts
+=head3 L<Capture::Tiny>
 
-=head3 L<Config::GitLike>
-
-=head3 L<DateTime>
+=head3 L<Config::JFDI>
 
 =head3 L<File::chdir>
 
@@ -135,29 +110,25 @@ Version 0.05 required because: for simple one-off scripts
 
 =head3 L<Path::Class>
 
-=head3 L<Plack>
-
 =head3 L<Readonly>
 
+=head3 L<Readonly::XS>
+
+=head3 L<Smart::Args>
+
+=head3 L<Smart::Comments>
+
 =head3 L<Sub::Install>
 
-=head3 L<Starman>
-
-=head3 L<Term::ReadLine::Gnu>
+=head3 L<Sub::Exporter>
 
 =head3 L<Try::Tiny>
 
 =head3 L<V>
 
-=head2 XS-speedups
+=head1 SEE ALSO
 
-Optional modules that make things faster when a compiler is available.
-
-=head3 L<Readonly::XS>
-
-=head2 People I wanna belike!
-
-=head3 L<Task::BeLike::RJBS> 20110324.000
+L<Task::BeLike::RSRCHBOY::Web>
 
 =head1 AUTHOR
 
@@ -175,3 +146,4 @@ This is free software, licensed under:
 
 
 __END__
+
